# Table of Contents

- [workspace-views](<./workspace-views.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Workspace Views](<./Workspace-Views.md>)
  - [Overview](<./Workspace-Views/Overview.md>)
  - [Using Workspace Views](<./Workspace-Views/Using-Workspace-Views.md>)
  - [Workspace Views Behavior](<./Workspace-Views/Workspace-Views-Behavior.md>)
